Module windows

Module windows 

Functions

current_acp
Get Current ANSI Code Page via Windows API
current_acp_encoding
current_acp_encoding_no_replacement
from_encoding
Returns the preferred code page identifier for an Encoding.
to_encoding
Maps a Windows code page identifier to an encoding_rs Encoding (or None if there is no appropriate mapping).
to_encoding_no_replacement
Like to_encoding, except returns None when to_encoding would return Some(REPLACEMENT).

Type Aliases

CodePage